<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>المصادقة مطلوبة لقراءة معلومات القرص</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>إن تشغيل مدير الأقرص يحتاج إلى مصادقة</translation>
		</message>
	</context>
</TS>